==> rosegarden-trinity-14.1.3.tar.xz: rosegarden-trinity-14.1.3/src/gui/studio/TimerCallbackAssistant.cpp <==
/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
 
    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>
 
    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.
 
    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/


#include "TimerCallbackAssistant.h"

#include <tqobject.h>
#include <tqtimer.h>


namespace Rosegarden
{

TimerCallbackAssistant::TimerCallbackAssistant(int ms, void (*callback)(void *data),
        void *data) :
        m_callback(callback),
        m_data(data)
{
    TQTimer *timer = new TQTimer(this);
    connect(timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotCallback()));
    timer->start(ms, FALSE);
}

TimerCallbackAssistant::~TimerCallbackAssistant()
{
    // nothing -- the TQTimer is deleted automatically by its parent TQObject (me)
}

void
TimerCallbackAssistant::slotCallback()
{
    m_callback(m_data);
}

}
#include "TimerCallbackAssistant.moc"

==> rosegarden-trinity_14.1.5.orig.tar.xz: rosegarden-trinity-14.1.5/src/gui/studio/TimerCallbackAssistant.cpp <==
/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
 
    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>
 
    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.
 
    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/


#include "TimerCallbackAssistant.h"

#include <tqobject.h>
#include <tqtimer.h>


namespace Rosegarden
{

TimerCallbackAssistant::TimerCallbackAssistant(int ms, void (*callback)(void *data),
        void *data) :
        m_callback(callback),
        m_data(data)
{
    TQTimer *timer = new TQTimer(this);
    connect(timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(slotCallback()));
    timer->start(ms, false);
}

TimerCallbackAssistant::~TimerCallbackAssistant()
{
    // nothing -- the TQTimer is deleted automatically by its parent TQObject (me)
}

void
TimerCallbackAssistant::slotCallback()
{
    m_callback(m_data);
}

}
#include "TimerCallbackAssistant.moc"
